import { __decorate, __metadata, __param } from 'tslib';
import { ElementRef, Input, Directive, InjectionToken, Inject, ɵɵdefineInjectable, ɵɵinject, Injectable, NgModule, Injector, INJECTOR, Pipe } from '@angular/core';
import { CommonModule, DatePipe } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { PopoverModule } from 'ngx-bootstrap/popover';
import { BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TimepickerModule } from 'ngx-bootstrap';
import { ToastrModule, ToastrService } from 'ngx-toastr';
import { MatSnackBarModule, MatSnackBar } from '@angular/material/snack-bar';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { map, startWith } from 'rxjs/operators';
import { forkJoin, BehaviorSubject, Subscription, interval } from 'rxjs';
import * as moment_ from 'moment';
import distanceInWordsToNow from 'date-fns/formatDistanceToNow';
import es from 'date-fns/locale/es';
import en from 'date-fns/locale/en-US';
import { DomSanitizer } from '@angular/platform-browser';
import { over } from 'stompjs';
import * as SockJS from 'sockjs-client';

var HighlightDirective = /** @class */ (function () {
    function HighlightDirective(el) {
        this.el = el;
        this.searchText = undefined;
        this.caseSensitive = true;
        this.viewRendered = false;
        this.WRAPPER_TOKEN = '==--==##';
    }
    Object.defineProperty(HighlightDirective.prototype, "caseSensitivity", {
        get: function () { return this.caseSensitive ? '' : 'i'; },
        enumerable: true,
        configurable: true
    });
    HighlightDirective.prototype.ngOnChanges = function (changes) {
        this.highlightSearchText();
    };
    HighlightDirective.prototype.ngAfterViewInit = function () {
        this.highlightSearchText();
    };
    HighlightDirective.prototype.ngAfterViewChecked = function () {
        this.viewRendered = true;
    };
    HighlightDirective.prototype.highlightSearchText = function () {
        // initial ngChage call will result with null \ undefined.
        if (!this.searchText) {
            // when user deletes all text the searchText is set to '' we need to remove all marks.
            if (this.viewRendered) {
                this.removePreviouslyMarkedTextInNode();
            }
            return;
        }
        if (this.el.nativeElement) {
            this.removePreviouslyMarkedTextInNode();
            this.markMatchedTextTokens(this.el.nativeElement);
        }
    };
    HighlightDirective.prototype.markMatchedTextTokens = function (htmlNode) {
        var _this = this;
        var _searchText = this.getSearchText();
        var searchRegex = new RegExp(_searchText, 'gm' + this.caseSensitivity);
        var _searchTextUniqueTokens = this.getUniqueTokenWrappedSearchText();
        var searchRegexUniqueTokens = new RegExp(_searchTextUniqueTokens, 'gm' + this.caseSensitivity);
        this.traverseHtmlElementsTree(htmlNode, function (e) {
            _this.traverseNodesInElement(htmlNode.childNodes, function (node) { return _this.wrapUniqueTokensAroundMatchedText(node, searchRegex); });
        });
        this.markMatchedTextAndRemoveUniqueTokens(htmlNode, searchRegexUniqueTokens);
    };
    HighlightDirective.prototype.markMatchedTextAndRemoveUniqueTokens = function (htmlNode, searchRegex) {
        var _this = this;
        if (htmlNode.innerHTML) {
            var innerHtml = htmlNode.innerHTML;
            var newHtml = innerHtml.replace(searchRegex, function (match) {
                var wrapperLength = _this.WRAPPER_TOKEN.length;
                var markedStr = match.substr(wrapperLength, match.length - (wrapperLength * 2));
                return "<mark>" + markedStr + "</mark>";
            });
            htmlNode.innerHTML = newHtml;
        }
    };
    HighlightDirective.prototype.traverseNodesInElement = function (nodes, visitCallback) {
        nodes.forEach(function (node) {
            if (node.nodeType === 3) {
                visitCallback(node);
            }
        });
    };
    HighlightDirective.prototype.wrapUniqueTokensAroundMatchedText = function (htmlNode, searchRegex) {
        var innerText = htmlNode.nodeValue;
        var newText = innerText.replace(searchRegex, this.WRAPPER_TOKEN + "$&" + this.WRAPPER_TOKEN);
        htmlNode.nodeValue = newText;
    };
    HighlightDirective.prototype.traverseHtmlElementsTree = function (currentNode, visitCallback) {
        if (currentNode) {
            visitCallback(currentNode);
        }
        /* tslint:disable:prefer-for-of */
        for (var i = 0; i < currentNode.children.length; i++) {
            var childNode = currentNode.children[i];
            this.markMatchedTextTokens(childNode);
        }
    };
    HighlightDirective.prototype.removePreviouslyMarkedTextInNode = function () {
        var node = this.el.nativeElement;
        var markingPattern = new RegExp('<mark>|<\/mark>', 'g');
        var cleanText = node.innerHTML.replace(markingPattern, '');
        node.innerHTML = cleanText;
    };
    // private highlightedNewTextInNode() {
    //   const node = this.el.nativeElement;
    //   const htmlNegativeLookaheadPattern = '(?![^<>]*>)';
    //   const searchTextPattern = this.getSearchText();
    //   const searchRegex = new RegExp(searchTextPattern + htmlNegativeLookaheadPattern, 'gmi');
    //   const markedText = node.innerHTML.replace(searchRegex, '<mark>$&</mark>');
    //   node.innerHTML = markedText;
    // }
    HighlightDirective.prototype.getSearchText = function () {
        var escapedSearchText = "" + this.escapeRegExp(this.searchText);
        var spaceToMultiMatchRegex = new RegExp(' ', 'gm' + this.caseSensitivity);
        escapedSearchText = escapedSearchText.replace(spaceToMultiMatchRegex, '|');
        return escapedSearchText;
    };
    HighlightDirective.prototype.getUniqueTokenWrappedSearchText = function () {
        var escapedSearchText = this.escapeRegExp(this.searchText);
        var spaceToMultiMatchRegex = new RegExp(' ', 'gm' + this.caseSensitivity);
        escapedSearchText = escapedSearchText.replace(spaceToMultiMatchRegex, this.WRAPPER_TOKEN + "|" + this.WRAPPER_TOKEN);
        escapedSearchText = "" + this.WRAPPER_TOKEN + escapedSearchText + this.WRAPPER_TOKEN;
        return escapedSearchText;
    };
    HighlightDirective.prototype.escapeRegExp = function (str) {
        return str.replace('/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/gi', '\\$&');
    };
    HighlightDirective.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], HighlightDirective.prototype, "searchText", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], HighlightDirective.prototype, "caseSensitive", void 0);
    HighlightDirective = __decorate([
        Directive({
            selector: '[xdfHighlight]'
        }),
        __metadata("design:paramtypes", [ElementRef])
    ], HighlightDirective);
    return HighlightDirective;
}());

var INITSERVICE_OPTIONS = new InjectionToken('forRoot() MyService configuration.');
var InitCommonsService = /** @class */ (function () {
    function InitCommonsService(config, translate, http) {
        this.config = config;
        this.translate = translate;
        this.http = http;
        this.definitionList = new Map();
        this.definitions = new Map();
    }
    InitCommonsService.prototype.initializeApp = function () {
        var _this = this;
        console.log('Init application');
        this.translate.setDefaultLang(this.config.language);
        return this.http.get('./assets/definitions/definitions.json').pipe(map(function (data) {
            var requestList = new Array();
            data.forEach(function (element) {
                var keys = Object.keys(element);
                var key = keys[0];
                var url = element[key];
                _this.definitionList.set(key, url);
                requestList.push(_this.http.get(url));
            });
            forkJoin(requestList).subscribe(function (list) {
                list.forEach(function (it) {
                    var keyName = 'name';
                    _this.definitions.set(it[keyName], it);
                });
            });
        })).toPromise();
    };
    InitCommonsService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [INITSERVICE_OPTIONS,] }] },
        { type: TranslateService },
        { type: HttpClient }
    ]; };
    InitCommonsService.ngInjectableDef = ɵɵdefineInjectable({ factory: function InitCommonsService_Factory() { return new InitCommonsService(ɵɵinject(INITSERVICE_OPTIONS), ɵɵinject(TranslateService), ɵɵinject(HttpClient)); }, token: InitCommonsService, providedIn: "root" });
    InitCommonsService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(INITSERVICE_OPTIONS)),
        __metadata("design:paramtypes", [Object, TranslateService,
            HttpClient])
    ], InitCommonsService);
    return InitCommonsService;
}());

var XdfCommonsModule = /** @class */ (function () {
    function XdfCommonsModule() {
    }
    XdfCommonsModule_1 = XdfCommonsModule;
    XdfCommonsModule.forRoot = function (options) {
        if (options === void 0) { options = null; }
        return ({
            ngModule: XdfCommonsModule_1,
            providers: [
                {
                    provide: INITSERVICE_OPTIONS,
                    useValue: options
                }
            ]
        });
    };
    var XdfCommonsModule_1;
    XdfCommonsModule = XdfCommonsModule_1 = __decorate([
        NgModule({
            declarations: [
                HighlightDirective
            ],
            imports: [
                FormsModule,
                CommonModule,
                ReactiveFormsModule,
                TranslateModule,
                ToastrModule.forRoot(),
                MatSnackBarModule,
                PopoverModule.forRoot(),
                BsDatepickerModule.forRoot(),
                TimepickerModule.forRoot()
            ],
            exports: []
        })
    ], XdfCommonsModule);
    return XdfCommonsModule;
}());

var Pagination = /** @class */ (function () {
    function Pagination() {
    }
    return Pagination;
}());
var DIRECTION = {
    asc: 'asc',
    desc: 'desc'
};
var SortField = /** @class */ (function () {
    function SortField() {
        this.direction = DIRECTION.asc;
    }
    return SortField;
}());

var User = /** @class */ (function () {
    function User() {
    }
    return User;
}());

var AuthenticationService = /** @class */ (function () {
    function AuthenticationService() {
        if (localStorage.getItem('currentUser') && localStorage.getItem('currentUser') !== 'undefined') {
            this.currentUserSubject = new BehaviorSubject(JSON.parse(localStorage.getItem('currentUser')));
            this.currentUser = this.currentUserSubject.asObservable();
        }
    }
    Object.defineProperty(AuthenticationService.prototype, "currentUserValue", {
        get: function () {
            return this.currentUserSubject ? this.currentUserSubject.value : undefined;
        },
        enumerable: true,
        configurable: true
    });
    AuthenticationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function AuthenticationService_Factory() { return new AuthenticationService(); }, token: AuthenticationService, providedIn: "root" });
    AuthenticationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [])
    ], AuthenticationService);
    return AuthenticationService;
}());

var NotificationType;
(function (NotificationType) {
    NotificationType["success"] = "success";
    NotificationType["info"] = "info";
    NotificationType["warning"] = "warning";
    NotificationType["error"] = "error";
})(NotificationType || (NotificationType = {}));
var NotificationService = /** @class */ (function () {
    function NotificationService() {
    }
    NotificationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function NotificationService_Factory() { return new NotificationService(); }, token: NotificationService, providedIn: "root" });
    NotificationService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], NotificationService);
    return NotificationService;
}());

var ToastNotificationService = /** @class */ (function () {
    function ToastNotificationService(injector, translate) {
        this.injector = injector;
        this.translate = translate;
        this.config = {
            closeButton: true,
            tapToDismiss: false,
            enableHtml: false,
            progressBar: false,
            newestOnTop: false,
            timeOut: 3000,
            positionClass: 'toast-top-right',
            extendedTimeOut: 1000,
            disableTimeOut: false,
            maxOpened: 0,
            easeTime: 300
        };
    }
    ToastNotificationService.prototype.showMessage = function (_message, _title, type) {
        if (_title === void 0) { _title = ''; }
        if (type === void 0) { type = NotificationType.info; }
        var toastr = this.injector.get(ToastrService);
        switch (type) {
            case NotificationType.success:
                toastr.success(_message, _title, this.config);
                break;
            case NotificationType.info:
                toastr.info(_message, _title, this.config);
                break;
            case NotificationType.warning:
                toastr.warning(_message, _title, this.config);
                break;
            case NotificationType.error:
                toastr.error(_message, _title, this.config);
                break;
        }
    };
    ToastNotificationService.ctorParameters = function () { return [
        { type: Injector },
        { type: TranslateService }
    ]; };
    ToastNotificationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function ToastNotificationService_Factory() { return new ToastNotificationService(ɵɵinject(INJECTOR), ɵɵinject(TranslateService)); }, token: ToastNotificationService, providedIn: "root" });
    ToastNotificationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [Injector, TranslateService])
    ], ToastNotificationService);
    return ToastNotificationService;
}());

var SnackbarNotificationService = /** @class */ (function () {
    function SnackbarNotificationService(injector, translate) {
        this.injector = injector;
        this.translate = translate;
    }
    SnackbarNotificationService.prototype.showMessage = function (message, title, type) {
        if (title === void 0) { title = ''; }
        if (type === void 0) { type = NotificationType.info; }
        var _snackBar = this.injector.get(MatSnackBar);
        switch (type) {
            case NotificationType.success:
                _snackBar.open(message, 'close', {
                    duration: 2000,
                    panelClass: ['success-snackbar']
                });
                break;
            case NotificationType.info:
                _snackBar.open(message, 'close', {
                    duration: 2000,
                    panelClass: ['info-snackbar']
                });
                break;
            case NotificationType.warning:
                _snackBar.open(message, 'close', {
                    duration: 2000,
                    panelClass: ['warning-snackbar']
                });
                break;
            case NotificationType.error:
                _snackBar.open(message, 'close', {
                    duration: 2000
                });
                break;
        }
    };
    SnackbarNotificationService.ctorParameters = function () { return [
        { type: Injector },
        { type: TranslateService }
    ]; };
    SnackbarNotificationService.ngInjectableDef = ɵɵdefineInjectable({ factory: function SnackbarNotificationService_Factory() { return new SnackbarNotificationService(ɵɵinject(INJECTOR), ɵɵinject(TranslateService)); }, token: SnackbarNotificationService, providedIn: "root" });
    SnackbarNotificationService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __metadata("design:paramtypes", [Injector, TranslateService])
    ], SnackbarNotificationService);
    return SnackbarNotificationService;
}());

var ErrorsHandler = /** @class */ (function () {
    function ErrorsHandler(notificationService, translate) {
        this.notificationService = notificationService;
        this.translate = translate;
    }
    ErrorsHandler.prototype.handleError = function (error) {
        if (!navigator.onLine) {
            // Handle offline error
            console.error('Browser Offline!');
        }
        else {
            console.error(error);
            if (error instanceof HttpErrorResponse) {
                // Server or connection error happened
                if (!navigator.onLine) {
                    // Handle offline error
                    console.error('Browser Offline!');
                }
                else {
                    // Handle Http Error (4xx, 5xx, ect.)
                    var messageError = error.error ? error.error : error.message;
                    this.notificationService.showMessage(messageError, this.translate.instant('title.http.error'), NotificationType.error);
                }
            }
            else {
                this.notificationService.showMessage(error.message, 'title.not.http.error!', NotificationType.error);
                console.error(error);
            }
            // Always log the error
            // console.error(error);
        }
    };
    ErrorsHandler.ctorParameters = function () { return [
        { type: NotificationService },
        { type: TranslateService }
    ]; };
    ErrorsHandler = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [NotificationService, TranslateService])
    ], ErrorsHandler);
    return ErrorsHandler;
}());

var moment = moment_;
var StringToDatePipe = /** @class */ (function () {
    function StringToDatePipe() {
    }
    StringToDatePipe.prototype.transform = function (value) {
        if (value === '' || value === null || value === undefined)
            return null;
        return moment(value).toDate();
    };
    StringToDatePipe = __decorate([
        Pipe({
            name: 'stringToDate'
        })
    ], StringToDatePipe);
    return StringToDatePipe;
}());

var StringToDateModule = /** @class */ (function () {
    function StringToDateModule() {
    }
    StringToDateModule = __decorate([
        NgModule({
            declarations: [
                StringToDatePipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                StringToDatePipe
            ]
        })
    ], StringToDateModule);
    return StringToDateModule;
}());

var SecondsToHoursMinutesPipe = /** @class */ (function () {
    function SecondsToHoursMinutesPipe() {
    }
    SecondsToHoursMinutesPipe.prototype.transform = function (totalSeconds) {
        if (!totalSeconds) {
            return '0';
        }
        var hours = Math.floor(totalSeconds / 3600);
        var minutes = Math.floor((totalSeconds % 3600) / 60);
        var seconds = totalSeconds % 60;
        var result = minutes.toString().padStart(1, '0') + ":" + seconds.toString().padStart(2, '0');
        if (!!hours) {
            result = hours.toString() + ":" + minutes.toString().padStart(2, '0') + ":" + seconds.toString().padStart(2, '0');
        }
        return result;
    };
    SecondsToHoursMinutesPipe = __decorate([
        Pipe({
            name: 'secondsToHoursMinutes'
        })
    ], SecondsToHoursMinutesPipe);
    return SecondsToHoursMinutesPipe;
}());

var SecondsToHoursMinutesModule = /** @class */ (function () {
    function SecondsToHoursMinutesModule() {
    }
    SecondsToHoursMinutesModule = __decorate([
        NgModule({
            declarations: [
                SecondsToHoursMinutesPipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                SecondsToHoursMinutesPipe
            ]
        })
    ], SecondsToHoursMinutesModule);
    return SecondsToHoursMinutesModule;
}());

var LocalizedDatePipe = /** @class */ (function () {
    function LocalizedDatePipe(config, translateService) {
        this.config = config;
        this.translateService = translateService;
    }
    LocalizedDatePipe.prototype.transform = function (value, pattern) {
        if (pattern === void 0) { pattern = 'mediumDate'; }
        var datePipe = new DatePipe(this.config.language);
        return datePipe.transform(value, pattern);
    };
    LocalizedDatePipe.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [INITSERVICE_OPTIONS,] }] },
        { type: TranslateService }
    ]; };
    LocalizedDatePipe = __decorate([
        Pipe({
            name: 'localizedDate', pure: false
        }),
        __param(0, Inject(INITSERVICE_OPTIONS)),
        __metadata("design:paramtypes", [Object, TranslateService])
    ], LocalizedDatePipe);
    return LocalizedDatePipe;
}());

var LocalizedDateModule = /** @class */ (function () {
    function LocalizedDateModule() {
    }
    LocalizedDateModule = __decorate([
        NgModule({
            declarations: [
                LocalizedDatePipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                LocalizedDatePipe
            ]
        })
    ], LocalizedDateModule);
    return LocalizedDateModule;
}());

var TruncatePipe = /** @class */ (function () {
    function TruncatePipe() {
    }
    TruncatePipe.prototype.transform = function (value, limit, completeWords, ellipsis) {
        if (limit === void 0) { limit = 25; }
        if (completeWords === void 0) { completeWords = false; }
        if (ellipsis === void 0) { ellipsis = '...'; }
        if (value.length < limit)
            return "" + value.substr(0, limit);
        if (completeWords) {
            limit = value.substr(0, limit).lastIndexOf(' ');
        }
        return "" + value.substr(0, limit) + ellipsis;
    };
    TruncatePipe = __decorate([
        Pipe({
            name: 'truncate'
        })
    ], TruncatePipe);
    return TruncatePipe;
}());

var TruncateModule = /** @class */ (function () {
    function TruncateModule() {
    }
    TruncateModule = __decorate([
        NgModule({
            declarations: [
                TruncatePipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                TruncatePipe
            ]
        })
    ], TruncateModule);
    return TruncateModule;
}());

var LeftPadPipe = /** @class */ (function () {
    function LeftPadPipe() {
    }
    LeftPadPipe.prototype.transform = function (value, size) {
        return (String('0').repeat(size) + value).substr((size * -1), size);
    };
    LeftPadPipe = __decorate([
        Pipe({
            name: 'leftPad'
        })
    ], LeftPadPipe);
    return LeftPadPipe;
}());

var LeftPadModule = /** @class */ (function () {
    function LeftPadModule() {
    }
    LeftPadModule = __decorate([
        NgModule({
            declarations: [
                LeftPadPipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                LeftPadPipe
            ]
        })
    ], LeftPadModule);
    return LeftPadModule;
}());

var locales = {
    en: en, es: es
};
var DateAgoPipe = /** @class */ (function () {
    function DateAgoPipe(config) {
        var _this = this;
        this.config = config;
        this.refresher = new Subscription();
        this.refreshNow = false;
        this.previousAgoExpression = '';
        this.refresher = interval(5000).pipe(startWith(0)).subscribe(function (_) { _this.refreshNow = true; });
    }
    DateAgoPipe.prototype.ngOnDestroy = function () {
        this.refresher.unsubscribe();
    };
    DateAgoPipe.prototype.transform = function (inputTime) {
        if (this.refreshNow) {
            this.refreshNow = false;
            var newAgoExpression = this.agoExpression(inputTime);
            this.previousAgoExpression = newAgoExpression;
            return newAgoExpression;
        }
        else {
            return this.previousAgoExpression;
        }
    };
    DateAgoPipe.prototype.agoExpression = function (inputTime) {
        var timeText = distanceInWordsToNow(inputTime, { includeSeconds: true, locale: locales[this.config.language] });
        return timeText;
    };
    DateAgoPipe.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [INITSERVICE_OPTIONS,] }] }
    ]; };
    DateAgoPipe = __decorate([
        Pipe({
            name: 'dateAgo', pure: false
        }),
        __param(0, Inject(INITSERVICE_OPTIONS)),
        __metadata("design:paramtypes", [Object])
    ], DateAgoPipe);
    return DateAgoPipe;
}());

var DateAgoModule = /** @class */ (function () {
    function DateAgoModule() {
    }
    DateAgoModule = __decorate([
        NgModule({
            declarations: [
                DateAgoPipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                DateAgoPipe
            ]
        })
    ], DateAgoModule);
    return DateAgoModule;
}());

var SanitizeHTMLPipe = /** @class */ (function () {
    function SanitizeHTMLPipe(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    SanitizeHTMLPipe.prototype.transform = function (html) {
        return this.domSanitizer.bypassSecurityTrustHtml(html);
    };
    SanitizeHTMLPipe.ctorParameters = function () { return [
        { type: DomSanitizer }
    ]; };
    SanitizeHTMLPipe = __decorate([
        Pipe({ name: 'sanitizeHTML' }),
        __metadata("design:paramtypes", [DomSanitizer])
    ], SanitizeHTMLPipe);
    return SanitizeHTMLPipe;
}());

var SanitizeHTMLModule = /** @class */ (function () {
    function SanitizeHTMLModule() {
    }
    SanitizeHTMLModule = __decorate([
        NgModule({
            declarations: [
                SanitizeHTMLPipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                SanitizeHTMLPipe
            ]
        })
    ], SanitizeHTMLModule);
    return SanitizeHTMLModule;
}());

var SanitizeStylePipe = /** @class */ (function () {
    function SanitizeStylePipe(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    SanitizeStylePipe.prototype.transform = function (css) {
        return this.domSanitizer.bypassSecurityTrustStyle(css);
    };
    SanitizeStylePipe.ctorParameters = function () { return [
        { type: DomSanitizer }
    ]; };
    SanitizeStylePipe = __decorate([
        Pipe({ name: 'sanitizeStyle' }),
        __metadata("design:paramtypes", [DomSanitizer])
    ], SanitizeStylePipe);
    return SanitizeStylePipe;
}());

var SanitizeStyleModule = /** @class */ (function () {
    function SanitizeStyleModule() {
    }
    SanitizeStyleModule = __decorate([
        NgModule({
            declarations: [
                SanitizeStylePipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                SanitizeStylePipe
            ]
        })
    ], SanitizeStyleModule);
    return SanitizeStyleModule;
}());

var BooleanToStringPipe = /** @class */ (function () {
    function BooleanToStringPipe() {
    }
    BooleanToStringPipe.prototype.transform = function (value) {
        if (value)
            return "label.boolean.true";
        return "label.boolean.false";
    };
    BooleanToStringPipe = __decorate([
        Pipe({
            name: 'booleanToString'
        })
    ], BooleanToStringPipe);
    return BooleanToStringPipe;
}());

var BooleanToStringModule = /** @class */ (function () {
    function BooleanToStringModule() {
    }
    BooleanToStringModule = __decorate([
        NgModule({
            declarations: [
                BooleanToStringPipe
            ],
            imports: [
                CommonModule
            ],
            exports: [
                BooleanToStringPipe
            ]
        })
    ], BooleanToStringModule);
    return BooleanToStringModule;
}());

var WebSocketAPI = /** @class */ (function () {
    function WebSocketAPI(socketMessageReceive, topic, webSocketEndPoint, zone) {
        if (webSocketEndPoint === void 0) { webSocketEndPoint = 'http://localhost:7070/ws'; }
        this.zone = zone;
        this.topic = topic;
        this.socketMessageReceive = socketMessageReceive;
        this.webSocketEndPoint = webSocketEndPoint;
    }
    WebSocketAPI.prototype._connect = function () {
        var _this = this;
        var ws = new SockJS(this.webSocketEndPoint);
        this.stompClient = over(ws);
        // remove console log
        this.stompClient.debug = null;
        var THIS = this;
        THIS.stompClient.connect({}, function (frame) {
            THIS.stompClient.subscribe(THIS.topic, function (event) {
                _this.zone.run(function () {
                    THIS.socketMessageReceive.onMessageReceived(JSON.parse(event.body));
                });
            });
        }, this.errorCallBack);
    };
    WebSocketAPI.prototype._disconnect = function () {
        if (this.stompClient !== null) {
            this.stompClient.disconnect();
        }
        console.log('Disconnected');
    };
    WebSocketAPI.prototype.errorCallBack = function (error) {
        var _this = this;
        console.log('errorCallBack -> ' + error);
        setTimeout(function () {
            _this._connect();
        }, 5000);
    };
    WebSocketAPI.prototype._sendMessage = function (channel, message) {
        this.stompClient.send(channel, {}, JSON.stringify(message));
    };
    return WebSocketAPI;
}());

/*
 * Public API Surface of xdf-commons
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationService, BooleanToStringModule, BooleanToStringPipe, DIRECTION, DateAgoModule, DateAgoPipe, ErrorsHandler, HighlightDirective, INITSERVICE_OPTIONS, InitCommonsService, LeftPadModule, LeftPadPipe, LocalizedDateModule, LocalizedDatePipe, NotificationService, NotificationType, Pagination, SanitizeHTMLModule, SanitizeHTMLPipe, SanitizeStyleModule, SanitizeStylePipe, SecondsToHoursMinutesModule, SecondsToHoursMinutesPipe, SnackbarNotificationService, SortField, StringToDateModule, StringToDatePipe, ToastNotificationService, TruncateModule, TruncatePipe, User, WebSocketAPI, XdfCommonsModule };
//# sourceMappingURL=xdf-commons.js.map
